Class: Google::Cloud::Memcache::V1beta2::LocationMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memcache/v1beta2/cloud_memcache.rb

Overview

Metadata for the given [google.cloud.location.Location][google.cloud.location.Location].

Defined Under Namespace

Classes: AvailableZonesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#available_zones ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Memcache::V1beta2::ZoneMetadata} (readonly)

Returns Output only. The set of available zones in the location. The map is keyed by the lowercase ID of each zone, as defined by GCE. These keys can be specified in the zones field when creating a Memcached instance.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::Memcache::V1beta2::ZoneMetadata}) —

    Output only. The set of available zones in the location. The map is keyed by the lowercase ID of each zone, as defined by GCE. These keys can be specified in the zones field when creating a Memcached instance.



436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'proto_docs/google/cloud/memcache/v1beta2/cloud_memcache.rb', line 436

class LocationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Memcache::V1beta2::ZoneMetadata]
  class AvailableZonesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end