Class: Google::Cloud::Memcache::V1beta2::UpdateParametersRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memcache/v1beta2/cloud_memcache.rb

Overview

Request for UpdateParameters.

Instance Attribute Summary collapse

Instance Attribute Details

#name ⇒ ::String

Returns Required. Resource name of the Memcached instance for which the parameters should be updated.

Returns:

  • (::String) —

    Required. Resource name of the Memcached instance for which the parameters should be updated.



351
352
353
354
# File 'proto_docs/google/cloud/memcache/v1beta2/cloud_memcache.rb', line 351

class UpdateParametersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parameters ⇒ ::Google::Cloud::Memcache::V1beta2::MemcacheParameters

Returns The parameters to apply to the instance.

Returns:



351
352
353
354
# File 'proto_docs/google/cloud/memcache/v1beta2/cloud_memcache.rb', line 351

class UpdateParametersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask ⇒ ::Google::Protobuf::FieldMask

Returns Required. Mask of fields to update.

Returns:



351
352
353
354
# File 'proto_docs/google/cloud/memcache/v1beta2/cloud_memcache.rb', line 351

class UpdateParametersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end