Class: Google::Cloud::Memcache::V1beta2::MemcacheParameters
- Inherits:
-
Object
- Object
- Google::Cloud::Memcache::V1beta2::MemcacheParameters
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/memcache/v1beta2/cloud_memcache.rb
Overview
The unique ID associated with this set of parameters. Users can use this id to determine if the parameters associated with the instance differ from the parameters associated with the nodes. A discrepancy between parameter ids can inform users that they may need to take action to apply parameters on nodes.
Defined Under Namespace
Classes: ParamsEntry
Instance Attribute Summary collapse
-
#id ⇒ ::String
readonly
Output only.
-
#params ⇒ ::Google::Protobuf::Map{::String => ::String}
User defined set of parameters to use in the memcached process.
Instance Attribute Details
#id ⇒ ::String (readonly)
Returns Output only.
386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'proto_docs/google/cloud/memcache/v1beta2/cloud_memcache.rb', line 386 class MemcacheParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ParamsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#params ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns User defined set of parameters to use in the memcached process.
386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'proto_docs/google/cloud/memcache/v1beta2/cloud_memcache.rb', line 386 class MemcacheParameters include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ParamsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |